pecos.error\_models.noise\_impl\_old.sq\_noise
==============================================

.. automodule:: pecos.error_models.noise_impl_old.sq_noise







   .. rubric:: Functions

   .. autosummary::

      noise_depolarizing_sq_gate
